# /packages/intranet-filestorage-size-indicator/tcl/intranet-filestorage-size-indicator-procs.tcl
#
# Copyright (c) 2015 ]project-open[ (Project Open Business Solutions, S.L.)
#
# All rights reserved. Please check
# http://www.project-open.com/en/project-open-license-commercial
#
# @author frank.bergmann@project-open.com

ad_library {
    @author frank.bergmann@project-open.com
}

# ----------------------------------------------------------------------
# Check the occupied pace
# ----------------------------------------------------------------------

ad_proc -public im_filestorage_size_indicator_sweeper { } {
    Check the space currently occupied by file storage
} {
    ns_log Notice "im_filestorage_size_indicator_sweeper: Starting"

    # ---------------------------------------------------
    # Calculate the used space
    #
    set serverroot [acs_root_dir]
    set filestorage_path "$serverroot/filestorage/"

    set du_output ""
    if {[catch {
	set du_output [exec /bin/bash -c "du -sk $filestorage_path"]
	ns_log Notice "im_filestorage_size_indicator_sweeper: du_output=$du_output"
    } err_msg]} { 
	ns_log Error "im_filestorage_size_indicator_sweeper: Error executing 'exec /bin/bash -c \"du -sk $filestorage_path\"': $err_msg"
	return
    }
    
    set size [string trim [lindex $du_output 0]]
    if {![string is integer $size]} {
	ns_log Error "im_filestorage_size_indicator_sweeper: 'du' value is not an integer: '$size' as first value from '$du_output'"
	return
    }

    set size [expr int($size / 1024)]
    db_dml update_filestorage_size "
	update apm_parameter_values
	set attr_value = :size
	where parameter_id in (
		select	parameter_id
		from	apm_parameters
		where	package_key = 'intranet-filestorage-size-indicator' and 
			parameter_name = 'CurrentlyOccupiedSpaceMB'
		)
    "

    # ---------------------------------------------------
    # Inform if the space gets low
    #
    set available_space [parameter::get_from_package_key -package_key "intranet-filestorage-size-indicator" -parameter AvailableSpaceMB -default "5120"]
    if {$size <= $available_space} { return }

    set system_name [ad_system_name]
    set sender_email [im_parameter -package_id [ad_acs_kernel_id] SystemOwner "" [ad_system_owner]]
    set system_owner_email [im_parameter -package_id [im_package_forum_id] ReportThisErrorEmail]
    set target_email [im_parameter -package_id [im_package_core_id] SecurityBreachEmail -default "support@project-open.com"]

    # Get intersting info
    set host [info hostname]
    set system_id [im_system_id]

    # Subject and body
    set subject [lang::message::lookup "" intranet-filestorage-size-indicator.Filestorage_Size_Exceeded_Subject "Filestorage Size Exceeded in %system_name%"]

    set body "AvailableSpace: $available_space MB
OccupiedSpace: $size MB

SystemID: $system_id
SystemName: $system_name
Managed by: $system_owner_email
Host: $host
"

    # Send out the mail
    if [catch {
        ns_sendmail $target_email $sender_email $subject $body
    } errmsg] {
        ns_log Error "im_filestorage_size_indicator_sweeper: Error sending to \"subject\": $errmsg"
    } else {
        ns_log Notice "im_send_alert: Sent mail to $target_email\n"
    }

}
